==> open-xchange-dav_7.4.1.orig.tar.bz2: open-xchange-dav-7.4.1/com.openexchange.caldav/src/com/openexchange/caldav/mixins/SupportedCalendarComponentSets.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.caldav.mixins;

import com.openexchange.caldav.CaldavProtocol;
import com.openexchange.java.StringAllocator;
import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;


/**
 * {@link SupportedCalendarComponentSets}
 *
 * Enumerates the sets of component restrictions the server is willing to allow the client to specify in MKCALENDAR or extended
 * MKCOL requests.
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class SupportedCalendarComponentSets extends SingleXMLPropertyMixin {

    public static final String VEVENT = "VEVENT";
    public static final String VTODO = "VTODO";

    private final String[] components;

    public SupportedCalendarComponentSets() {
        this(VEVENT);
    }

    /**
     * Initializes a new {@link SupportedCalendarComponentSets}.
     *
     * @param components The supported calendar components
     */
    public SupportedCalendarComponentSets(String...components) {
        super(CaldavProtocol.CAL_NS.getURI(), "supported-calendar-component-sets");
        this.components = components;
    }

    @Override
    protected String getValue() {
        if (null != this.components) {

            StringAllocator stringAllocator = new StringAllocator("");
            for (String component : components) {
                stringAllocator.append("<CAL:supported-calendar-component-set><CAL:comp name=\"")
                    .append(component).append("\"/></CAL:supported-calendar-component-set>");
            }
            return stringAllocator.toString();
//            StringAllocator stringAllocator = new StringAllocator("<CAL:supported-calendar-component-set>");
//            for (String component : components) {
//                stringAllocator.append("<CAL:comp name=\"").append(component).append("\"/>");
//            }
//            stringAllocator.append("</CAL:supported-calendar-component-set>");
//            return stringAllocator.toString();
        }
        return null;
    }

}

==> open-xchange-dav_7.6.1.orig.tar.bz2: open-xchange-dav-7.6.1/com.openexchange.caldav/src/com/openexchange/caldav/mixins/SupportedCalendarComponentSets.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.caldav.mixins;

import com.openexchange.caldav.CaldavProtocol;
import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;


/**
 * {@link SupportedCalendarComponentSets}
 *
 * Enumerates the sets of component restrictions the server is willing to allow the client to specify in MKCALENDAR or extended
 * MKCOL requests.
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class SupportedCalendarComponentSets extends SingleXMLPropertyMixin {

    public static final String VEVENT = "VEVENT";
    public static final String VTODO = "VTODO";

    private final String[] components;

    public SupportedCalendarComponentSets() {
        this(VEVENT);
    }

    /**
     * Initializes a new {@link SupportedCalendarComponentSets}.
     *
     * @param components The supported calendar components
     */
    public SupportedCalendarComponentSets(String...components) {
        super(CaldavProtocol.CAL_NS.getURI(), "supported-calendar-component-sets");
        this.components = components;
    }

    @Override
    protected String getValue() {
        if (null != this.components) {

            StringBuilder StringBuilder = new StringBuilder("");
            for (String component : components) {
                StringBuilder.append("<CAL:supported-calendar-component-set><CAL:comp name=\"")
                    .append(component).append("\"/></CAL:supported-calendar-component-set>");
            }
            return StringBuilder.toString();
//            StringBuilder StringBuilder = new StringBuilder("<CAL:supported-calendar-component-set>");
//            for (String component : components) {
//                StringBuilder.append("<CAL:comp name=\"").append(component).append("\"/>");
//            }
//            StringBuilder.append("</CAL:supported-calendar-component-set>");
//            return StringBuilder.toString();
        }
        return null;
    }

}
